@@ -279,6 +279,11 @@ class EngagementRateIG:
                     df_posts_full = pd.merge(
                         df_posts_full, df_fan_count, on=["owner_id"], how="left"
                     )
+                    df_posts_full = df_posts_full.rename(
+                        columns={"date_x":"date"}
+                    )
+                    df_posts_full = df_posts_full.drop(columns=["date_y"])
+                    
                     df_posts_full["followers"] = df_posts_full.sort_values(
                         ["owner_id", "date"]
                     )["followers"].fillna(method="bfill")
